import { type OptionValues as CliOptionValues } from "commander";
import { type Workspace } from "../utils/workspace.js";
import type { AdderConfig } from "./config.js";
export type BooleanDefaultValue = {
    type: "boolean";
    default: boolean;
};
export type StringDefaultValue = {
    type: "string";
    default: string;
};
export type NumberDefaultValue = {
    type: "number";
    default: number;
};
export type BaseQuestion = {
    question: string;
};
export type BooleanQuestion = BaseQuestion & BooleanDefaultValue;
export type StringQuestion = BaseQuestion & StringDefaultValue;
export type NumberQuestion = BaseQuestion & NumberDefaultValue;
export type Question = BooleanQuestion | StringQuestion | NumberQuestion;
export type OptionDefinition = Record<string, Question>;
export type OptionValues<Args extends OptionDefinition> = {
    [K in keyof Args]: Args[K]["type"] extends "string" ? string : Args[K]["type"] extends "boolean" ? boolean : Args[K]["type"] extends "number" ? number : never;
};
export declare function prepareAndParseCliOptions<Args extends OptionDefinition>(config: AdderConfig<Args>): CliOptionValues;
export declare function askQuestionsAndAssignValuesToWorkspace<Args extends OptionDefinition>(config: AdderConfig<Args>, workspace: Workspace<Args>, cliOptions: CliOptionValues): Promise<void>;
export declare function ensureCorrectOptionTypes<Args extends OptionDefinition>(config: AdderConfig<Args>, workspace: Workspace<Args>): void;
